<a id="mypy-boto3-quicksight"></a>

# mypy-boto3-quicksight

[![PyPI - mypy-boto3-quicksight](https://img.shields.io/pypi/v/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-quicksight.svg?color=blue)](https://pypi.org/project/mypy-boto3-quicksight)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-quicksight?color=blue)](https://pypistats.org/packages/mypy-boto3-quicksight)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.QuickSight 1.17.101](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/quicksight.html#QuickSight)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.20.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-quicksight](#mypy-boto3-quicksight)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `QuickSight` service.

```bash
python -m pip install boto3-stubs[quicksight]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`

Both type checking and auto-complete should work for `QuickSight` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Run `mypy` as usual

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[quicksight]` in your environment:
  `python -m pip install 'boto3-stubs[quicksight]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `QuickSight` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`QuickSightClient` provides annotations for `boto3.client("quicksight")`.

```python
import boto3

from mypy_boto3_quicksight import QuickSightClient

client: QuickSightClient = boto3.client("quicksight")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: QuickSightClient = session.client("quicksight")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_quicksight.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_quicksight import QuickSightClient
from mypy_boto3_quicksight.paginator import (
    ListAnalysesPaginator,
    ListDashboardVersionsPaginator,
    ListDashboardsPaginator,
    ListDataSetsPaginator,
    ListDataSourcesPaginator,
    ListIngestionsPaginator,
    ListNamespacesPaginator,
    ListTemplateAliasesPaginator,
    ListTemplateVersionsPaginator,
    ListTemplatesPaginator,
    ListThemeVersionsPaginator,
    ListThemesPaginator,
    SearchAnalysesPaginator,
    SearchDashboardsPaginator,
)

client: QuickSightClient = boto3.client("quicksight")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_analyses_paginator: ListAnalysesPaginator = client.get_paginator("list_analyses")
list_dashboard_versions_paginator: ListDashboardVersionsPaginator = client.get_paginator("list_dashboard_versions")
list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
list_data_sets_paginator: ListDataSetsPaginator = client.get_paginator("list_data_sets")
list_data_sources_paginator: ListDataSourcesPaginator = client.get_paginator("list_data_sources")
list_ingestions_paginator: ListIngestionsPaginator = client.get_paginator("list_ingestions")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_template_aliases_paginator: ListTemplateAliasesPaginator = client.get_paginator("list_template_aliases")
list_template_versions_paginator: ListTemplateVersionsPaginator = client.get_paginator("list_template_versions")
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
list_theme_versions_paginator: ListThemeVersionsPaginator = client.get_paginator("list_theme_versions")
list_themes_paginator: ListThemesPaginator = client.get_paginator("list_themes")
search_analyses_paginator: SearchAnalysesPaginator = client.get_paginator("search_analyses")
search_dashboards_paginator: SearchDashboardsPaginator = client.get_paginator("search_dashboards")
```

<a id="literals"></a>

### Literals

`mypy_boto3_quicksight.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_quicksight.literals import (
    AnalysisErrorTypeType,
    AnalysisFilterAttributeType,
    AssignmentStatusType,
    ColumnDataTypeType,
    DashboardBehaviorType,
    DashboardErrorTypeType,
    DashboardFilterAttributeType,
    DashboardUIStateType,
    DataSetImportModeType,
    DataSourceErrorInfoTypeType,
    DataSourceTypeType,
    EditionType,
    EmbeddingIdentityTypeType,
    FileFormatType,
    FilterOperatorType,
    FolderFilterAttributeType,
    FolderTypeType,
    GeoSpatialCountryCodeType,
    GeoSpatialDataRoleType,
    IdentityStoreType,
    IdentityTypeType,
    IngestionErrorTypeType,
    IngestionRequestSourceType,
    IngestionRequestTypeType,
    IngestionStatusType,
    InputColumnDataTypeType,
    JoinTypeType,
    ListAnalysesPaginatorName,
    ListDashboardVersionsPaginatorName,
    ListDashboardsPaginatorName,
    ListDataSetsPaginatorName,
    ListDataSourcesPaginatorName,
    ListIngestionsPaginatorName,
    ListNamespacesPaginatorName,
    ListTemplateAliasesPaginatorName,
    ListTemplateVersionsPaginatorName,
    ListTemplatesPaginatorName,
    ListThemeVersionsPaginatorName,
    ListThemesPaginatorName,
    MemberTypeType,
    NamespaceErrorTypeType,
    NamespaceStatusType,
    ResourceStatusType,
    RowLevelPermissionFormatVersionType,
    RowLevelPermissionPolicyType,
    SearchAnalysesPaginatorName,
    SearchDashboardsPaginatorName,
    TemplateErrorTypeType,
    TextQualifierType,
    ThemeErrorTypeType,
    ThemeTypeType,
    UserRoleType,
)

def check_value(value: AnalysisErrorTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_quicksight.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_quicksight.type_defs import (
    AccountCustomizationTypeDef,
    AccountSettingsTypeDef,
    ActiveIAMPolicyAssignmentTypeDef,
    AdHocFilteringOptionTypeDef,
    AmazonElasticsearchParametersTypeDef,
    AnalysisErrorTypeDef,
    AnalysisSearchFilterTypeDef,
    AnalysisSourceEntityTypeDef,
    AnalysisSourceTemplateTypeDef,
    AnalysisSummaryTypeDef,
    AnalysisTypeDef,
    AthenaParametersTypeDef,
    AuroraParametersTypeDef,
    AuroraPostgreSqlParametersTypeDef,
    AwsIotAnalyticsParametersTypeDef,
    BorderStyleTypeDef,
    CalculatedColumnTypeDef,
    CancelIngestionRequestTypeDef,
    CancelIngestionResponseResponseTypeDef,
    CastColumnTypeOperationTypeDef,
    ColumnDescriptionTypeDef,
    ColumnGroupColumnSchemaTypeDef,
    ColumnGroupSchemaTypeDef,
    ColumnGroupTypeDef,
    ColumnLevelPermissionRuleTypeDef,
    ColumnSchemaTypeDef,
    ColumnTagTypeDef,
    CreateAccountCustomizationRequestTypeDef,
    CreateAccountCustomizationResponseResponseTypeDef,
    CreateAnalysisRequestTypeDef,
    CreateAnalysisResponseResponseTypeDef,
    CreateColumnsOperationTypeDef,
    CreateDashboardRequestTypeDef,
    CreateDashboardResponseResponseTypeDef,
    CreateDataSetRequestTypeDef,
    CreateDataSetResponseResponseTypeDef,
    CreateDataSourceRequestTypeDef,
    CreateDataSourceResponseResponseTypeDef,
    CreateFolderMembershipRequestTypeDef,
    CreateFolderMembershipResponseResponseTypeDef,
    CreateFolderRequestTypeDef,
    CreateFolderResponseResponseTypeDef,
    CreateGroupMembershipRequestTypeDef,
    CreateGroupMembershipResponseResponseTypeDef,
    CreateGroupRequestTypeDef,
    CreateGroupResponseResponseTypeDef,
    CreateIAMPolicyAssignmentRequestTypeDef,
    CreateIAMPolicyAssignmentResponseResponseTypeDef,
    CreateIngestionRequestTypeDef,
    CreateIngestionResponseResponseTypeDef,
    CreateNamespaceRequestTypeDef,
    CreateNamespaceResponseResponseTypeDef,
    CreateTemplateAliasRequestTypeDef,
    CreateTemplateAliasResponseResponseTypeDef,
    CreateTemplateRequestTypeDef,
    CreateTemplateResponseResponseTypeDef,
    CreateThemeAliasRequestTypeDef,
    CreateThemeAliasResponseResponseTypeDef,
    CreateThemeRequestTypeDef,
    CreateThemeResponseResponseTypeDef,
    CredentialPairTypeDef,
    CustomSqlTypeDef,
    DashboardErrorTypeDef,
    DashboardPublishOptionsTypeDef,
    DashboardSearchFilterTypeDef,
    DashboardSourceEntityTypeDef,
    DashboardSourceTemplateTypeDef,
    DashboardSummaryTypeDef,
    DashboardTypeDef,
    DashboardVersionSummaryTypeDef,
    DashboardVersionTypeDef,
    DataColorPaletteTypeDef,
    DataSetConfigurationTypeDef,
    DataSetReferenceTypeDef,
    DataSetSchemaTypeDef,
    DataSetSummaryTypeDef,
    DataSetTypeDef,
    DataSourceCredentialsTypeDef,
    DataSourceErrorInfoTypeDef,
    DataSourceParametersTypeDef,
    DataSourceTypeDef,
    DateTimeParameterTypeDef,
    DecimalParameterTypeDef,
    DeleteAccountCustomizationRequestTypeDef,
    DeleteAccountCustomizationResponseResponseTypeDef,
    DeleteAnalysisRequestTypeDef,
    DeleteAnalysisResponseResponseTypeDef,
    DeleteDashboardRequestTypeDef,
    DeleteDashboardResponseResponseTypeDef,
    DeleteDataSetRequestTypeDef,
    DeleteDataSetResponseResponseTypeDef,
    DeleteDataSourceRequestTypeDef,
    DeleteDataSourceResponseResponseTypeDef,
    DeleteFolderMembershipRequestTypeDef,
    DeleteFolderMembershipResponseResponseTypeDef,
    DeleteFolderRequestTypeDef,
    DeleteFolderResponseResponseTypeDef,
    DeleteGroupMembershipRequestTypeDef,
    DeleteGroupMembershipResponseResponseTypeDef,
    DeleteGroupRequestTypeDef,
    DeleteGroupResponseResponseTypeDef,
    DeleteIAMPolicyAssignmentRequestTypeDef,
    DeleteIAMPolicyAssignmentResponseResponseTypeDef,
    DeleteNamespaceRequestTypeDef,
    DeleteNamespaceResponseResponseTypeDef,
    DeleteTemplateAliasRequestTypeDef,
    DeleteTemplateAliasResponseResponseTypeDef,
    DeleteTemplateRequestTypeDef,
    DeleteTemplateResponseResponseTypeDef,
    DeleteThemeAliasRequestTypeDef,
    DeleteThemeAliasResponseResponseTypeDef,
    DeleteThemeRequestTypeDef,
    DeleteThemeResponseResponseTypeDef,
    DeleteUserByPrincipalIdRequestTypeDef,
    DeleteUserByPrincipalIdResponseResponseTypeDef,
    DeleteUserRequestTypeDef,
    DeleteUserResponseResponseTypeDef,
    DescribeAccountCustomizationRequestTypeDef,
    DescribeAccountCustomizationResponseResponseTypeDef,
    DescribeAccountSettingsRequestTypeDef,
    DescribeAccountSettingsResponseResponseTypeDef,
    DescribeAnalysisPermissionsRequestTypeDef,
    DescribeAnalysisPermissionsResponseResponseTypeDef,
    DescribeAnalysisRequestTypeDef,
    DescribeAnalysisResponseResponseTypeDef,
    DescribeDashboardPermissionsRequestTypeDef,
    DescribeDashboardPermissionsResponseResponseTypeDef,
    DescribeDashboardRequestTypeDef,
    DescribeDashboardResponseResponseTypeDef,
    DescribeDataSetPermissionsRequestTypeDef,
    DescribeDataSetPermissionsResponseResponseTypeDef,
    DescribeDataSetRequestTypeDef,
    DescribeDataSetResponseResponseTypeDef,
    DescribeDataSourcePermissionsRequestTypeDef,
    DescribeDataSourcePermissionsResponseResponseTypeDef,
    DescribeDataSourceRequestTypeDef,
    DescribeDataSourceResponseResponseTypeDef,
    DescribeFolderPermissionsRequestTypeDef,
    DescribeFolderPermissionsResponseResponseTypeDef,
    DescribeFolderRequestTypeDef,
    DescribeFolderResolvedPermissionsRequestTypeDef,
    DescribeFolderResolvedPermissionsResponseResponseTypeDef,
    DescribeFolderResponseResponseTypeDef,
    DescribeGroupRequestTypeDef,
    DescribeGroupResponseResponseTypeDef,
    DescribeIAMPolicyAssignmentRequestTypeDef,
    DescribeIAMPolicyAssignmentResponseResponseTypeDef,
    DescribeIngestionRequestTypeDef,
    DescribeIngestionResponseResponseTypeDef,
    DescribeNamespaceRequestTypeDef,
    DescribeNamespaceResponseResponseTypeDef,
    DescribeTemplateAliasRequestTypeDef,
    DescribeTemplateAliasResponseResponseTypeDef,
    DescribeTemplatePermissionsRequestTypeDef,
    DescribeTemplatePermissionsResponseResponseTypeDef,
    DescribeTemplateRequestTypeDef,
    DescribeTemplateResponseResponseTypeDef,
    DescribeThemeAliasRequestTypeDef,
    DescribeThemeAliasResponseResponseTypeDef,
    DescribeThemePermissionsRequestTypeDef,
    DescribeThemePermissionsResponseResponseTypeDef,
    DescribeThemeRequestTypeDef,
    DescribeThemeResponseResponseTypeDef,
    DescribeUserRequestTypeDef,
    DescribeUserResponseResponseTypeDef,
    ErrorInfoTypeDef,
    ExportToCSVOptionTypeDef,
    FieldFolderTypeDef,
    FilterOperationTypeDef,
    FolderMemberTypeDef,
    FolderSearchFilterTypeDef,
    FolderSummaryTypeDef,
    FolderTypeDef,
    GeoSpatialColumnGroupTypeDef,
    GetDashboardEmbedUrlRequestTypeDef,
    GetDashboardEmbedUrlResponseResponseTypeDef,
    GetSessionEmbedUrlRequestTypeDef,
    GetSessionEmbedUrlResponseResponseTypeDef,
    GroupMemberTypeDef,
    GroupTypeDef,
    GutterStyleTypeDef,
    IAMPolicyAssignmentSummaryTypeDef,
    IAMPolicyAssignmentTypeDef,
    IngestionTypeDef,
    InputColumnTypeDef,
    IntegerParameterTypeDef,
    JiraParametersTypeDef,
    JoinInstructionTypeDef,
    JoinKeyPropertiesTypeDef,
    ListAnalysesRequestTypeDef,
    ListAnalysesResponseResponseTypeDef,
    ListDashboardVersionsRequestTypeDef,
    ListDashboardVersionsResponseResponseTypeDef,
    ListDashboardsRequestTypeDef,
    ListDashboardsResponseResponseTypeDef,
    ListDataSetsRequestTypeDef,
    ListDataSetsResponseResponseTypeDef,
    ListDataSourcesRequestTypeDef,
    ListDataSourcesResponseResponseTypeDef,
    ListFolderMembersRequestTypeDef,
    ListFolderMembersResponseResponseTypeDef,
    ListFoldersRequestTypeDef,
    ListFoldersResponseResponseTypeDef,
    ListGroupMembershipsRequestTypeDef,
    ListGroupMembershipsResponseResponseTypeDef,
    ListGroupsRequestTypeDef,
    ListGroupsResponseResponseTypeDef,
    ListIAMPolicyAssignmentsForUserRequestTypeDef,
    ListIAMPolicyAssignmentsForUserResponseResponseTypeDef,
    ListIAMPolicyAssignmentsRequestTypeDef,
    ListIAMPolicyAssignmentsResponseResponseTypeDef,
    ListIngestionsRequestTypeDef,
    ListIngestionsResponseResponseTypeDef,
    ListNamespacesRequestTypeDef,
    ListNamespacesResponseResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseResponseTypeDef,
    ListTemplateAliasesRequestTypeDef,
    ListTemplateAliasesResponseResponseTypeDef,
    ListTemplateVersionsRequestTypeDef,
    ListTemplateVersionsResponseResponseTypeDef,
    ListTemplatesRequestTypeDef,
    ListTemplatesResponseResponseTypeDef,
    ListThemeAliasesRequestTypeDef,
    ListThemeAliasesResponseResponseTypeDef,
    ListThemeVersionsRequestTypeDef,
    ListThemeVersionsResponseResponseTypeDef,
    ListThemesRequestTypeDef,
    ListThemesResponseResponseTypeDef,
    ListUserGroupsRequestTypeDef,
    ListUserGroupsResponseResponseTypeDef,
    ListUsersRequestTypeDef,
    ListUsersResponseResponseTypeDef,
    LogicalTableSourceTypeDef,
    LogicalTableTypeDef,
    ManifestFileLocationTypeDef,
    MarginStyleTypeDef,
    MariaDbParametersTypeDef,
    MemberIdArnPairTypeDef,
    MySqlParametersTypeDef,
    NamespaceErrorTypeDef,
    NamespaceInfoV2TypeDef,
    OracleParametersTypeDef,
    OutputColumnTypeDef,
    PaginatorConfigTypeDef,
    ParametersTypeDef,
    PhysicalTableTypeDef,
    PostgreSqlParametersTypeDef,
    PrestoParametersTypeDef,
    ProjectOperationTypeDef,
    QueueInfoTypeDef,
    RdsParametersTypeDef,
    RedshiftParametersTypeDef,
    RegisterUserRequestTypeDef,
    RegisterUserResponseResponseTypeDef,
    RelationalTableTypeDef,
    RenameColumnOperationTypeDef,
    ResourcePermissionTypeDef,
    ResponseMetadataTypeDef,
    RestoreAnalysisRequestTypeDef,
    RestoreAnalysisResponseResponseTypeDef,
    RowInfoTypeDef,
    RowLevelPermissionDataSetTypeDef,
    S3ParametersTypeDef,
    S3SourceTypeDef,
    SearchAnalysesRequestTypeDef,
    SearchAnalysesResponseResponseTypeDef,
    SearchDashboardsRequestTypeDef,
    SearchDashboardsResponseResponseTypeDef,
    SearchFoldersRequestTypeDef,
    SearchFoldersResponseResponseTypeDef,
    ServiceNowParametersTypeDef,
    SheetControlsOptionTypeDef,
    SheetStyleTypeDef,
    SheetTypeDef,
    SnowflakeParametersTypeDef,
    SparkParametersTypeDef,
    SqlServerParametersTypeDef,
    SslPropertiesTypeDef,
    StringParameterTypeDef,
    TagColumnOperationTypeDef,
    TagResourceRequestTypeDef,
    TagResourceResponseResponseTypeDef,
    TagTypeDef,
    TemplateAliasTypeDef,
    TemplateErrorTypeDef,
    TemplateSourceAnalysisTypeDef,
    TemplateSourceEntityTypeDef,
    TemplateSourceTemplateTypeDef,
    TemplateSummaryTypeDef,
    TemplateTypeDef,
    TemplateVersionSummaryTypeDef,
    TemplateVersionTypeDef,
    TeradataParametersTypeDef,
    ThemeAliasTypeDef,
    ThemeConfigurationTypeDef,
    ThemeErrorTypeDef,
    ThemeSummaryTypeDef,
    ThemeTypeDef,
    ThemeVersionSummaryTypeDef,
    ThemeVersionTypeDef,
    TileLayoutStyleTypeDef,
    TileStyleTypeDef,
    TransformOperationTypeDef,
    TwitterParametersTypeDef,
    UIColorPaletteTypeDef,
    UntagResourceRequestTypeDef,
    UntagResourceResponseResponseTypeDef,
    UpdateAccountCustomizationRequestTypeDef,
    UpdateAccountCustomizationResponseResponseTypeDef,
    UpdateAccountSettingsRequestTypeDef,
    UpdateAccountSettingsResponseResponseTypeDef,
    UpdateAnalysisPermissionsRequestTypeDef,
    UpdateAnalysisPermissionsResponseResponseTypeDef,
    UpdateAnalysisRequestTypeDef,
    UpdateAnalysisResponseResponseTypeDef,
    UpdateDashboardPermissionsRequestTypeDef,
    UpdateDashboardPermissionsResponseResponseTypeDef,
    UpdateDashboardPublishedVersionRequestTypeDef,
    UpdateDashboardPublishedVersionResponseResponseTypeDef,
    UpdateDashboardRequestTypeDef,
    UpdateDashboardResponseResponseTypeDef,
    UpdateDataSetPermissionsRequestTypeDef,
    UpdateDataSetPermissionsResponseResponseTypeDef,
    UpdateDataSetRequestTypeDef,
    UpdateDataSetResponseResponseTypeDef,
    UpdateDataSourcePermissionsRequestTypeDef,
    UpdateDataSourcePermissionsResponseResponseTypeDef,
    UpdateDataSourceRequestTypeDef,
    UpdateDataSourceResponseResponseTypeDef,
    UpdateFolderPermissionsRequestTypeDef,
    UpdateFolderPermissionsResponseResponseTypeDef,
    UpdateFolderRequestTypeDef,
    UpdateFolderResponseResponseTypeDef,
    UpdateGroupRequestTypeDef,
    UpdateGroupResponseResponseTypeDef,
    UpdateIAMPolicyAssignmentRequestTypeDef,
    UpdateIAMPolicyAssignmentResponseResponseTypeDef,
    UpdateTemplateAliasRequestTypeDef,
    UpdateTemplateAliasResponseResponseTypeDef,
    UpdateTemplatePermissionsRequestTypeDef,
    UpdateTemplatePermissionsResponseResponseTypeDef,
    UpdateTemplateRequestTypeDef,
    UpdateTemplateResponseResponseTypeDef,
    UpdateThemeAliasRequestTypeDef,
    UpdateThemeAliasResponseResponseTypeDef,
    UpdateThemePermissionsRequestTypeDef,
    UpdateThemePermissionsResponseResponseTypeDef,
    UpdateThemeRequestTypeDef,
    UpdateThemeResponseResponseTypeDef,
    UpdateUserRequestTypeDef,
    UpdateUserResponseResponseTypeDef,
    UploadSettingsTypeDef,
    UserTypeDef,
    VpcConnectionPropertiesTypeDef,
)

def get_structure() -> AccountCustomizationTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-quicksight` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-quicksight docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_quicksight/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
